==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_service_get_geolocations_response_200_geos_item_states_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetGeolocationsResponse_200GeosItemStatesItem")


@attr.s(auto_attribs=True)
class PoolService_GetGeolocationsResponse_200GeosItemStatesItem:
    """ Pool Allocation of Remaining Principal Balance """

    rpb: Union[Unset, float] = UNSET
    loans: Union[Unset, int] = UNSET
    name: Union[Unset, str] = UNSET
    percentage_rpb: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rpb = self.rpb
        loans = self.loans
        name = self.name
        percentage_rpb = self.percentage_rpb

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rpb is not UNSET:
            field_dict["RPB"] = rpb
        if loans is not UNSET:
            field_dict["loans"] = loans
        if name is not UNSET:
            field_dict["name"] = name
        if percentage_rpb is not UNSET:
            field_dict["percentageRPB"] = percentage_rpb

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        rpb = d.pop("RPB", UNSET)

        loans = d.pop("loans", UNSET)

        name = d.pop("name", UNSET)

        percentage_rpb = d.pop("percentageRPB", UNSET)

        pool_service_get_geolocations_response_200_geos_item_states_item = cls(
            rpb=rpb,
            loans=loans,
            name=name,
            percentage_rpb=percentage_rpb,
        )

        pool_service_get_geolocations_response_200_geos_item_states_item.additional_properties = (
            d
        )
        return pool_service_get_geolocations_response_200_geos_item_states_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_service_get_geolocations_response_200_geos_item_states_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetGeolocationsResponse_200GeosItemStatesItem")


@attr.s(auto_attribs=True)
class PoolService_GetGeolocationsResponse_200GeosItemStatesItem:
    """ Pool Allocation of Remaining Principal Balance """

    loans: Union[Unset, int] = UNSET
    name: Union[Unset, str] = UNSET
    percentage_rpb: Union[Unset, float] = UNSET
    rpb: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        loans = self.loans
        name = self.name
        percentage_rpb = self.percentage_rpb
        rpb = self.rpb

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if loans is not UNSET:
            field_dict["loans"] = loans
        if name is not UNSET:
            field_dict["name"] = name
        if percentage_rpb is not UNSET:
            field_dict["percentageRpb"] = percentage_rpb
        if rpb is not UNSET:
            field_dict["rpb"] = rpb

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        loans = d.pop("loans", UNSET)

        name = d.pop("name", UNSET)

        percentage_rpb = d.pop("percentageRpb", UNSET)

        rpb = d.pop("rpb", UNSET)

        pool_service_get_geolocations_response_200_geos_item_states_item = cls(
            loans=loans,
            name=name,
            percentage_rpb=percentage_rpb,
            rpb=rpb,
        )

        pool_service_get_geolocations_response_200_geos_item_states_item.additional_properties = (
            d
        )
        return pool_service_get_geolocations_response_200_geos_item_states_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
